@@ -18,6 +18,79 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class BindAutoScalingGroupRequest(AbstractModel):
+    """BindAutoScalingGroup请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterId: 集群ID。
+        :type ClusterId: str
+        :param LaunchConfigurationId: 弹性伸缩启动配置ID。
+        :type LaunchConfigurationId: str
+        :param AutoScalingGroupId: 弹性伸缩组ID。
+        :type AutoScalingGroupId: str
+        :param ExpansionBusyTime: 任务连续等待时间，队列的任务处于连续等待的时间。单位秒。默认值120。
+        :type ExpansionBusyTime: int
+        :param ShrinkIdleTime: 节点连续空闲（未运行作业）时间，一个节点连续处于空闲状态时间。单位秒。默认值300。
+        :type ShrinkIdleTime: int
+        :param EnableAutoExpansion: 是否开启自动扩容，默认值true。
+        :type EnableAutoExpansion: bool
+        :param EnableAutoShrink: 是否开启自动缩容，默认值true。
+        :type EnableAutoShrink: bool
+        :param DryRun: 是否只预检此次请求。
+true：发送检查请求，不会绑定弹性伸缩组。检查项包括是否填写了必需参数，请求格式，业务限制。
+如果检查不通过，则返回对应错误码；
+如果检查通过，则返回RequestId。
+false（默认）：发送正常请求，通过检查后直接绑定弹性伸缩组。
+        :type DryRun: bool
+        """
+        self.ClusterId = None
+        self.LaunchConfigurationId = None
+        self.AutoScalingGroupId = None
+        self.ExpansionBusyTime = None
+        self.ShrinkIdleTime = None
+        self.EnableAutoExpansion = None
+        self.EnableAutoShrink = None
+        self.DryRun = None
+
+
+    def _deserialize(self, params):
+        self.ClusterId = params.get("ClusterId")
+        self.LaunchConfigurationId = params.get("LaunchConfigurationId")
+        self.AutoScalingGroupId = params.get("AutoScalingGroupId")
+        self.ExpansionBusyTime = params.get("ExpansionBusyTime")
+        self.ShrinkIdleTime = params.get("ShrinkIdleTime")
+        self.EnableAutoExpansion = params.get("EnableAutoExpansion")
+        self.EnableAutoShrink = params.get("EnableAutoShrink")
+        self.DryRun = params.get("DryRun")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class BindAutoScalingGroupResponse(AbstractModel):
+    """BindAutoScalingGroup返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class CFSOption(AbstractModel):
     """描述CFS文件系统版本和挂载信息
 
@@ -31,7 +104,7 @@ class CFSOption(AbstractModel):
         :type RemotePath: str
         :param Protocol: 文件系统协议类型，默认值NFS 3.0
         :type Protocol: str
-        :param StorageType: 文件系统存储类型，默认值SD
+        :param StorageType: 文件系统存储类型，默认值SD；其中 SD 为通用标准型标准型存储， HP为通用性能型存储， TB为turbo标准型， TP 为turbo性能型。
         :type StorageType: str
         """
         self.LocalPath = None
@@ -54,6 +127,78 @@ class CFSOption(AbstractModel):
         
 
 
+class ClusterOverview(AbstractModel):
+    """集群概览信息。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterId: 集群ID。
+        :type ClusterId: str
+        :param ClusterStatus: 集群状态。取值范围：<br><li>PENDING：创建中<br><li>INITING：初始化中<br><li>INIT_FAILED：初始化失败<br><li>RUNNING：运行中<br><li>TERMINATING：销毁中
+        :type ClusterStatus: str
+        :param ClusterName: 集群名称。
+        :type ClusterName: str
+        :param Placement: 集群位置信息。
+        :type Placement: :class:`tencentcloud.thpc.v20211109.models.Placement`
+        :param CreateTime: 集群创建时间。
+        :type CreateTime: str
+        :param SchedulerType: 集群调度器。
+        :type SchedulerType: str
+        :param ComputeNodeCount: 计算节点数量。
+        :type ComputeNodeCount: int
+        :param ComputeNodeSet: 计算节点概览。
+        :type ComputeNodeSet: list of ComputeNodeOverview
+        :param ManagerNodeCount: 管控节点数量。
+        :type ManagerNodeCount: int
+        :param ManagerNodeSet: 管控节点概览。
+        :type ManagerNodeSet: list of ManagerNodeOverview
+        """
+        self.ClusterId = None
+        self.ClusterStatus = None
+        self.ClusterName = None
+        self.Placement = None
+        self.CreateTime = None
+        self.SchedulerType = None
+        self.ComputeNodeCount = None
+        self.ComputeNodeSet = None
+        self.ManagerNodeCount = None
+        self.ManagerNodeSet = None
+
+
+    def _deserialize(self, params):
+        self.ClusterId = params.get("ClusterId")
+        self.ClusterStatus = params.get("ClusterStatus")
+        self.ClusterName = params.get("ClusterName")
+        if params.get("Placement") is not None:
+            self.Placement = Placement()
+            self.Placement._deserialize(params.get("Placement"))
+        self.CreateTime = params.get("CreateTime")
+        self.SchedulerType = params.get("SchedulerType")
+        self.ComputeNodeCount = params.get("ComputeNodeCount")
+        if params.get("ComputeNodeSet") is not None:
+            self.ComputeNodeSet = []
+            for item in params.get("ComputeNodeSet"):
+                obj = ComputeNodeOverview()
+                obj._deserialize(item)
+                self.ComputeNodeSet.append(obj)
+        self.ManagerNodeCount = params.get("ManagerNodeCount")
+        if params.get("ManagerNodeSet") is not None:
+            self.ManagerNodeSet = []
+            for item in params.get("ManagerNodeSet"):
+                obj = ManagerNodeOverview()
+                obj._deserialize(item)
+                self.ManagerNodeSet.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class ComputeNode(AbstractModel):
     """计算节点信息。
 
@@ -72,13 +217,11 @@ class ComputeNode(AbstractModel):
         :type SystemDisk: :class:`tencentcloud.thpc.v20211109.models.SystemDisk`
         :param DataDisks: 节点数据盘配置信息。若不指定该参数，则默认不购买数据盘。支持购买的时候指定21块数据盘，其中最多包含1块LOCAL_BASIC数据盘或者LOCAL_SSD数据盘，最多包含20块CLOUD_BASIC数据盘、CLOUD_PREMIUM数据盘或者CLOUD_SSD数据盘。
         :type DataDisks: list of DataDisk
-        :param InternetAccessible: 公网带宽相关信息设置。若不指定该参数，则默认公网带宽为0Mbps。
+        :param InternetAccessible: 节点数据盘配置信息。若不指定该参数，则默认不购买数据盘。支持购买的时候指定21块数据盘，其中最多包含1块LOCAL_BASIC数据盘或者LOCAL_SSD数据盘，最多包含20块CLOUD_BASIC数据盘、CLOUD_PREMIUM数据盘或者CLOUD_SSD数据盘。
         :type InternetAccessible: :class:`tencentcloud.thpc.v20211109.models.InternetAccessible`
         :param InstanceName: 节点显示名称。<br><li>
 不指定节点显示名称则默认显示‘未命名’。
-</li><li>购买多个节点，如果指定模式串`{R:x}`，表示生成数字[`[x, x+n-1]`，其中`n`表示购买节点的数量，例如`server_{R:3}`，购买1个时，节点显示名称为`server_3`；购买2个时，节点显示名称分别为`server_3`，`server_4`。支持指定多个模式串`{R:x}`。
-购买多个节点，如果不指定模式串，则在节点显示名称添加后缀`1、2...n`，其中`n`表示购买节点的数量，例如`server_`，购买2个时，节点显示名称分别为`server_1`，`server_2`。</li><li>
-最多支持60个字符（包含模式串）。
+最多支持60个字符。
         :type InstanceName: str
         """
         self.InstanceChargeType = None
@@ -118,6 +261,31 @@ class ComputeNode(AbstractModel):
         
 
 
+class ComputeNodeOverview(AbstractModel):
+    """计算节点概览。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param NodeId: 计算节点ID。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NodeId: str
+        """
+        self.NodeId = None
+
+
+    def _deserialize(self, params):
+        self.NodeId = params.get("NodeId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class CreateClusterRequest(AbstractModel):
     """CreateCluster请求参数结构体
 
@@ -135,7 +303,7 @@ class CreateClusterRequest(AbstractModel):
         :type ComputeNode: :class:`tencentcloud.thpc.v20211109.models.ComputeNode`
         :param ComputeNodeCount: 指定计算节点的数量。默认取值：0。
         :type ComputeNodeCount: int
-        :param SchedulerType: 调度器类型。目前仅支持SGE调度器。
+        :param SchedulerType: 调度器类型。<br><li>SGE：SGE调度器。
         :type SchedulerType: str
         :param ImageId: 指定有效的[镜像](https://cloud.tencent.com/document/product/213/4940)ID，格式形如`img-xxx`。目前仅支持公有镜像和自定义镜像。
         :type ImageId: str
@@ -153,7 +321,7 @@ true：发送检查请求，不会创建实例。检查项包括是否填写了
 如果检查通过，则返回RequestId.
 false（默认）：发送正常请求，通过检查后直接创建实例
         :type DryRun: bool
-        :param AccountType: 域名字服务类型。目前仅支持NIS域名字服务。
+        :param AccountType: 域名字服务类型。<br><li>NIS：NIS域名字服务。
         :type AccountType: str
         :param ClusterName: 集群显示名称。
         :type ClusterName: str
@@ -222,6 +390,7 @@ class CreateClusterResponse(AbstractModel):
     def __init__(self):
         r"""
         :param ClusterId: 集群ID。
+注意：此字段可能返回 null，表示取不到有效值。
         :type ClusterId: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -304,6 +473,100 @@ class DeleteClusterResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeClustersRequest(AbstractModel):
+    """DescribeClusters请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterIds: 集群ID列表。通过该参数可以指定需要查询信息的集群列表。<br>如果您不指定该参数，则返回Limit数量以内的集群信息。
+        :type ClusterIds: list of str
+        :param Offset: 偏移量，默认为0。关于`Offset`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/15688)中的相关小节。
+        :type Offset: int
+        :param Limit: 返回数量，默认为20，最大值为100。关于`Limit`的更进一步介绍请参考 API [简介](https://cloud.tencent.com/document/api/213/15688)中的相关小节。
+        :type Limit: int
+        """
+        self.ClusterIds = None
+        self.Offset = None
+        self.Limit = None
+
+
+    def _deserialize(self, params):
+        self.ClusterIds = params.get("ClusterIds")
+        self.Offset = params.get("Offset")
+        self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeClustersResponse(AbstractModel):
+    """DescribeClusters返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ClusterSet: 集群概览信息列表。
+        :type ClusterSet: list of ClusterOverview
+        :param TotalCount: 集群数量。
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ClusterSet = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ClusterSet") is not None:
+            self.ClusterSet = []
+            for item in params.get("ClusterSet"):
+                obj = ClusterOverview()
+                obj._deserialize(item)
+                self.ClusterSet.append(obj)
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
+class GooseFSOption(AbstractModel):
+    """描述GooseFS挂载信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param LocalPath: 文件系统本地挂载路径
+        :type LocalPath: str
+        :param RemotePath: 文件系统远程挂载路径
+        :type RemotePath: str
+        :param Masters: 文件系统master的ip和端口
+        :type Masters: list of str
+        """
+        self.LocalPath = None
+        self.RemotePath = None
+        self.Masters = None
+
+
+    def _deserialize(self, params):
+        self.LocalPath = params.get("LocalPath")
+        self.RemotePath = params.get("RemotePath")
+        self.Masters = params.get("Masters")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class InstanceChargePrepaid(AbstractModel):
     """描述了实例的计费模式
 
@@ -458,6 +721,31 @@ class ManagerNode(AbstractModel):
         
 
 
+class ManagerNodeOverview(AbstractModel):
+    """管控节点概览。
+
+    """
+
+    def __init__(self):
+        r"""
+        :param NodeId: 管控节点ID。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NodeId: str
+        """
+        self.NodeId = None
+
+
+    def _deserialize(self, params):
+        self.NodeId = params.get("NodeId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class Placement(AbstractModel):
     """描述了实例的抽象位置
 
@@ -491,8 +779,11 @@ class StorageOption(AbstractModel):
         r"""
         :param CFSOptions: 集群挂载CFS文件系统选项
         :type CFSOptions: list of CFSOption
+        :param GooseFSOptions: 集群挂在GooseFS文件系统选项
+        :type GooseFSOptions: list of GooseFSOption
         """
         self.CFSOptions = None
+        self.GooseFSOptions = None
 
 
     def _deserialize(self, params):
@@ -502,6 +793,12 @@ class StorageOption(AbstractModel):
                 obj = CFSOption()
                 obj._deserialize(item)
                 self.CFSOptions.append(obj)
+        if params.get("GooseFSOptions") is not None:
+            self.GooseFSOptions = []
+            for item in params.get("GooseFSOptions"):
+                obj = GooseFSOption()
+                obj._deserialize(item)
+                self.GooseFSOptions.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
